<?php

namespace Chemical\Export\Policies;

use Litepie\User\Contracts\UserPolicy;
use Chemical\Export\Models\Export;

class ExportPolicy
{

    /**
     * Determine if the given user can view the export.
     *
     * @param UserPolicy $user
     * @param Export $export
     *
     * @return bool
     */
    public function view(UserPolicy $user, Export $export)
    {
        if ($user->canDo('export.export.view') && $user->isAdmin()) {
            return true;
        }

        return $export->user_id == user_id() && $export->user_type == user_type();
    }

    /**
     * Determine if the given user can create a export.
     *
     * @param UserPolicy $user
     * @param Export $export
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('export.export.create');
    }

    /**
     * Determine if the given user can update the given export.
     *
     * @param UserPolicy $user
     * @param Export $export
     *
     * @return bool
     */
    public function update(UserPolicy $user, Export $export)
    {
        if ($user->canDo('export.export.edit') && $user->isAdmin()) {
            return true;
        }

        return $export->user_id == user_id() && $export->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given export.
     *
     * @param UserPolicy $user
     * @param Export $export
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Export $export)
    {
        return $export->user_id == user_id() && $export->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given export.
     *
     * @param UserPolicy $user
     * @param Export $export
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Export $export)
    {
        if ($user->canDo('export.export.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given export.
     *
     * @param UserPolicy $user
     * @param Export $export
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Export $export)
    {
        if ($user->canDo('export.export.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
